@@ -107,7 +107,7 @@ class Insight_Definition:
         r = self.__make_put_request(url, body)
         self.components = r.json()["components"]
 
-    def add_widget(self, widget_type: str, query_ids:list=[], settings:dict={}, values:dict={}, texts:dict={}, charts:list=[], multiple= False):
+    def add_widget(self, widget_type: str, query_ids:list=[], settings:dict={}, values:dict={}, texts:dict={}, charts:list=[], multiple=False):
         position = (len(self.components))
         widget_id = self.__create_widget(position, widget_type)
         if(query_ids!=[]):
@@ -215,7 +215,7 @@ class Insight_Definition:
                         else:
                             ids.append(column["id"])
 
-            if(len(ids>1)):
+            if(len(ids)>1):
                 settings[field + "_id"] = ids
             else:
                 settings[field + "_id"] = ids[0]
